@@ -6,6 +6,7 @@ from Acquisition import aq_inner
 from Acquisition import aq_parent
 from datetime import datetime
 from dateutil import tz
+from decimal import Decimal
 from euphorie import MessageFactory as _
 from euphorie.client import config
 from euphorie.client.adapters.session_traversal import ITraversedSurveySession
@@ -37,8 +38,7 @@ from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.utils import getToolByName
 from Products.Five import BrowserView
 from Products.statusmessages.interfaces import IStatusMessage
-from z3c.appconfig.interfaces import IAppConfig
-from z3c.appconfig.utils import asBool
+from six.moves.urllib.parse import urlencode
 from ZODB.POSException import POSKeyError
 from zope.component import getMultiAdapter
 from zope.component import getUtility
@@ -46,9 +46,6 @@ from zope.component.hooks import getSite
 from zope.deprecation import deprecate
 from zope.i18nmessageid import MessageFactory
 
-import Globals
-import urllib
-
 
 pl_message = MessageFactory("plonelocales")
 pae_message = MessageFactory("plone.app.event")
@@ -104,6 +101,10 @@ class WebHelpers(BrowserView):
     group_model = Group
     survey_session_model = SurveySession
 
+    def to_decimal(self, value):
+        """Transform value in to a decimal"""
+        return Decimal(value)
+
     @property
     @memoize
     def resources_timestamp(self):
@@ -126,48 +127,56 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def debug_mode(self):
-        return Globals.DevelopmentMode
-
-    @property
-    @memoize
-    def _settings(self):
-        appconfig = getUtility(IAppConfig)
-        return appconfig.get("euphorie")
+        return api.env.debug_mode()
 
     @property
     @memoize
     def allow_social_sharing(self):
-        return asBool(self._settings.get("allow_social_sharing", False))
+        return api.portal.get_registry_record(
+            "euphorie.allow_social_sharing", default=False
+        )
 
     @property
     @memoize
     def allow_guest_accounts(self):
-        return asBool(self._settings.get("allow_guest_accounts", False))
+        return api.portal.get_registry_record(
+            "euphorie.allow_guest_accounts", default=False
+        )
 
     @property
     @memoize
     def use_involve_phase(self):
-        return asBool(self._settings.get("use_involve_phase", False))
+        return api.portal.get_registry_record(
+            "euphorie.use_involve_phase", default=False
+        )
 
     @property
     @memoize
     def use_training_module(self):
-        return asBool(self._settings.get("use_training_module", False))
+        return api.portal.get_registry_record(
+            "euphorie.use_training_module", default=False
+        )
 
     @property
     @memoize
     def use_publication_feature(self):
-        return asBool(self._settings.get("use_publication_feature", False))
+        return api.portal.get_registry_record(
+            "euphorie.use_publication_feature", default=False
+        )
 
     @property
     @memoize
     def use_clone_feature(self):
-        return asBool(self._settings.get("use_clone_feature", False))
+        return api.portal.get_registry_record(
+            "euphorie.use_clone_feature", default=False
+        )
 
     @property
     @memoize
     def use_archive_feature(self):
-        return asBool(self._settings.get("use_archive_feature", False))
+        return api.portal.get_registry_record(
+            "euphorie.use_archive_feature", default=False
+        )
 
     @property
     @memoize
@@ -183,7 +192,7 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def default_country(self):
-        return self._settings.get("default_country", "")
+        return api.portal.get_registry_record("euphorie.default_country", default=u"")
 
     @property
     @memoize
@@ -590,10 +599,10 @@ class WebHelpers(BrowserView):
             # If the tool has a notification message, we cannot allow to deeplink
             # into it, since the user might then miss the notificaton.
             if not self.tool_notification():
-                return urllib.urlencode({"came_from": self.came_from})
+                return urlencode({"came_from": self.came_from})
             survey_url = self.survey_url()
             if survey_url:
-                return urllib.urlencode({"came_from": survey_url})
+                return urlencode({"came_from": survey_url})
         return ""
 
     @property
@@ -690,7 +699,9 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def integrated_action_plan(self):
-        if not asBool(self._settings.get("use_integrated_action_plan", False)):
+        if not api.portal.get_registry_record(
+            "euphorie.use_integrated_action_plan", default=False
+        ):
             return False
         return getattr(self._survey, "integrated_action_plan", False)
 
