@@ -8,21 +8,20 @@ client user.
 
 from borg.localrole.interfaces import ILocalRoleProvider
 from euphorie.client.interfaces import IClientSkinLayer
-from five import grok
 from plone.app.dexterity.behaviors.metadata import IBasic
 from plone.dexterity.content import Container
-from plone.directives import form
+from plone.supermodel import model
 from Products.membrane.interfaces.user import IMembraneUserObject
-from zope.component import adapts
+from zope.component import adapter
 from zope.interface import directlyProvidedBy
 from zope.interface import directlyProvides
-from zope.interface import implements
+from zope.interface import implementer
 from zope.interface import Interface
 from zope.publisher.interfaces.browser import IBrowserSkinType
 from ZPublisher.BaseRequest import DefaultPublishTraverse
 
 
-class IClient(form.Schema, IBasic):
+class IClient(model.Schema, IBasic):
     """The online client.
 
     The online client is implemented as a container with all available surveys.
@@ -32,20 +31,22 @@ class IClient(form.Schema, IBasic):
     """
 
 
+@implementer(IClient)
 class Client(Container):
-    implements(IClient)
 
     exclude_from_nav = True
 
 
-class ClientUserProvider(grok.Adapter):
+@adapter(IClient)
+@implementer(IMembraneUserObject)
+class ClientUserProvider(object):
     """Expose the client as a user to the system.
 
     This is used as ownership for all client data.
     """
 
-    grok.context(IClient)
-    grok.implements(IMembraneUserObject)
+    def __init__(self, context):
+        self.context = context
 
     def getUserId(self):
         return self.context.id
@@ -54,7 +55,9 @@ class ClientUserProvider(grok.Adapter):
         return self.context.id
 
 
-class ClientLocalRolesProvider(grok.Adapter):
+@adapter(IClient)
+@implementer(ILocalRoleProvider)
+class ClientLocalRolesProvider(object):
     """`borg.localrole` provider for :obj:`IClient` instances.
 
     This local role provider gives the client user itself the
@@ -63,9 +66,6 @@ class ClientLocalRolesProvider(grok.Adapter):
     runs under the client user.
     """
 
-    grok.context(IClient)
-    grok.implements(ILocalRoleProvider)
-
     def __init__(self, client):
         self.context = client
 
@@ -78,6 +78,7 @@ class ClientLocalRolesProvider(grok.Adapter):
         return [(self.context.getId(), ("CountryManager",))]
 
 
+@adapter(IClient, Interface)
 class ClientPublishTraverser(DefaultPublishTraverse):
     """Publish traverser to setup the skin layer.
 
@@ -85,8 +86,6 @@ class ClientPublishTraverser(DefaultPublishTraverse):
     BeforeTraverseEvent since in Zope 2 that is only fired for site objects.
     """
 
-    adapts(IClient, Interface)
-
     def publishTraverse(self, request, name):
         from euphorie.client.utils import setRequest
 
