@@ -8,16 +8,21 @@ SQL-based individual session content of the client users.
 Also: PAS-based user account for users of the client
 """
 from __future__ import division
+from AccessControl.interfaces import IUser
 from AccessControl.PermissionRole import _what_not_even_god_should_do
+from AccessControl.SecurityInfo import ClassSecurityInfo
+from Acquisition import aq_inner
+from Acquisition import aq_parent
 from collections import defaultdict
 from euphorie.client.enum import Enum
+from OFS.interfaces import IApplication
 from plone import api
 from plone.app.event.base import localized_now
 from plone.memoize import ram
 from plone.memoize.instance import memoize
+from Products.CMFPlone.utils import safe_nativestring
 from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
-from Products.PluggableAuthService.interfaces.authservice import IBasicUser
 from sqlalchemy import orm
 from sqlalchemy import schema
 from sqlalchemy import sql
@@ -73,10 +78,41 @@ class BaseObject(OFS.Traversable.Traversable, Acquisition.Implicit):
 
     __init__ = declarative.api._declarative_constructor
     __allow_access_to_unprotected_subobjects__ = True
+    __new__ = object.__new__
+
+    security = ClassSecurityInfo()
 
     def getId(self):
         return str(self.id)
 
+    @security.public
+    def getPhysicalPath(self):
+        # Get the physical path of the object.
+        #
+        # We need to override this because the new Zope implementations
+        # uses self.id instead of self.getId, which make a big difference in our case
+        id = self.getId()
+
+        path = (id,)
+        p = aq_parent(aq_inner(self))
+        if p is None:
+            return path
+
+        func = self.getPhysicalPath.__func__
+        while p is not None:
+            if func is p.getPhysicalPath.__func__:
+                pid = p.getId()
+                path = (pid,) + path
+                p = aq_parent(aq_inner(p))
+            else:
+                if IApplication.providedBy(p):
+                    path = ("",) + path
+                else:
+                    path = p.getPhysicalPath() + path
+                break
+
+        return path
+
 
 class SurveyTreeItem(BaseObject):
     """A tree of questions.
@@ -321,7 +357,7 @@ class Group(BaseObject):
             if not new_ids:
                 return
             ids.extend(new_ids)
-            map(get_ids, new_ids)
+            tuple(map(get_ids, new_ids))
 
         get_ids(self.group_id)
         return ids
@@ -382,7 +418,7 @@ class Group(BaseObject):
         )
 
 
-@implementer(IBasicUser)
+@implementer(IUser)
 class Account(BaseObject):
     """A user account. Users have to register with euphorie before they can
     start a survey session. A single account can have multiple survey sessions.
@@ -513,8 +549,7 @@ class Account(BaseObject):
             return False
         if password == self.password:
             return True
-        if isinstance(password, six.text_type):
-            password = password.encode("utf8")
+        password = safe_nativestring(password)
         return bcrypt.checkpw(password, self.password)
 
     def hash_password(self):
@@ -525,16 +560,17 @@ class Account(BaseObject):
             return
         if not password:
             return
-        if isinstance(password, six.text_type):
-            password = password.encode("utf8")
+        password = safe_nativestring(password)
         if BCRYPTED_PATTERN.match(password):
             # The password is already encrypted, do not encrypt it again
             # XXX this is broken with passwords that are actually an hash
             return
-        self.password = bcrypt.hashpw(
-            password,
-            bcrypt.gensalt(),
-        ).decode("utf8")
+        self.password = safe_unicode(
+            bcrypt.hashpw(
+                password,
+                bcrypt.gensalt(),
+            )
+        )
 
 
 def account_before_insert_subscriber(mapper, connection, account):
