@@ -6,23 +6,18 @@ Helper functions.
 """
 
 from .. import MessageFactory as _
-from email.Header import Header
-from email.MIMEMultipart import MIMEMultipart
-from email.MIMEText import MIMEText
+from email.header import Header
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
 from euphorie.client import model
-from euphorie.client.interfaces import IClientSkinLayer
 from euphorie.content.utils import StripMarkup
-from five import grok
 from plone import api
-from plonetheme.nuplone.skin.interfaces import NuPloneSkin
 from Products.CMFCore.utils import getToolByName
 from sqlalchemy import sql
 from z3c.saconfig import Session
 from zope.i18nmessageid import MessageFactory
-from zope.interface import Interface
 
-import email.Utils as emailutils
-import htmllib
+import email.utils as emailutils
 import logging
 import random
 import six
@@ -32,7 +27,6 @@ import threading
 locals = threading.local()
 log = logging.getLogger(__name__)
 
-grok.templatedir("templates")
 pl_message = MessageFactory("plonelocales")
 
 
@@ -55,9 +49,7 @@ def getSecret():
 def randomString(length=16):
     """Return 32 bytes of random data. Only characters which do not require
     special escaping in HTML or URLs are generated."""
-    safe_characters = (
-        "abcdefghijklmnopqrstuvwxyz" "ABCDEFGHIJKLMNOPQRSTUVWXYZ" "1234567890-"
-    )
+    safe_characters = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890-"
     return "".join(random.choice(safe_characters) for idx in range(length))
 
 
@@ -108,7 +100,7 @@ def setLanguage(request, context, lang=None):
         lang = lang.split("-")[0]
         res = lt.setLanguageCookie(lang=lang, request=request)
         if res is None:
-            log.warn("Failed to switch language to %s", lang)
+            log.warning("Failed to switch language to %s", lang)
             lt.setLanguageCookie(lang="en", request=request)
             lang = "en"
 
@@ -121,37 +113,6 @@ def setLanguage(request, context, lang=None):
         binding.LANGUAGE = lang
 
 
-class DefaultIntroduction(grok.View):
-    """
-    Browser view that displays the default introduction text for a Suvey.
-    It is used when the Survey does not define its own introduction
-    """
-
-    grok.context(Interface)
-    grok.layer(IClientSkinLayer)
-    grok.name("default_introduction")
-    grok.template("default_introduction")
-
-
-class ContentDefaultIntroduction(grok.View):
-    """
-    Browser view that displays the default introduction text for a Suvey.
-    It is used when the Survey does not define its own introduction
-    """
-
-    grok.context(Interface)
-    grok.layer(NuPloneSkin)
-    grok.name("default_introduction")
-    grok.template("default_introduction")
-
-
-def html_unescape(s):
-    p = htmllib.HTMLParser(None)
-    p.save_bgn()
-    p.feed(s)
-    return p.save_end()
-
-
 def remove_empty_modules(nodes):
     """Takes a list of modules and risks.
 
@@ -187,7 +148,7 @@ def remove_empty_modules(nodes):
                 tree[(node.path, node.type, node.id)] = {}
 
     def prune(tree):
-        for k in tree.keys():
+        for k in list(tree):
             if tree[k]:
                 prune(tree[k])
 
