@@ -1,30 +1,33 @@
 from OFS.event import ObjectClonedEvent
 from OFS.interfaces import IObjectClonedEvent
-from zope.component.interfaces import IObjectEvent
-from zope.component.interfaces import ObjectEvent
-from zope.interface import implements
+from plonetheme.nuplone.skin.interfaces import NuPloneSkin
+from zope.interface import implementer
 from zope.interface import Interface
+from zope.interface.interfaces import IObjectEvent
+from zope.interface.interfaces import ObjectEvent
+
+
+class IEuphorieContentLayer(NuPloneSkin):
+    """Marker interface for Euphorie content"""
 
 
 class IObjectPublishedEvent(IObjectClonedEvent):
     """An object has been published by copying it to the client area."""
 
 
+@implementer(IObjectPublishedEvent)
 class ObjectPublishedEvent(ObjectClonedEvent):
     """An object has been published by copying it to the client area."""
 
-    implements(IObjectPublishedEvent)
-
 
 class ISurveyUnpublishEvent(IObjectEvent):
     """A survey is being removed from the client."""
 
 
+@implementer(ISurveyUnpublishEvent)
 class SurveyUnpublishEvent(ObjectEvent):
     """A survey is being removed from the client."""
 
-    implements(ISurveyUnpublishEvent)
-
 
 class IQuestionContainer(Interface):
     """Marker interface for objects that are used for grouping, but
