@@ -1,6 +1,9 @@
 # coding=utf-8
 from euphorie.testing import EuphorieFunctionalTestCase
 from euphorie.testing import EuphorieIntegrationTestCase
+from plone import api
+from plone.app.testing import SITE_OWNER_NAME
+from plone.app.testing import SITE_OWNER_PASSWORD
 from transaction import commit
 
 
@@ -20,7 +23,7 @@ class ModuleTests(EuphorieIntegrationTestCase):
     def testNotGloballyAllowed(self):
         self.loginAsPortalOwner()
         types = [fti.id for fti in self.portal.allowedContentTypes()]
-        self.failUnless("euphorie.module" not in types)
+        self.assertTrue("euphorie.module" not in types)
 
     def testAllowedContentTypes(self):
         self.loginAsPortalOwner()
@@ -32,7 +35,7 @@ class ModuleTests(EuphorieIntegrationTestCase):
         from euphorie.content.fti import ConditionalDexterityFTI
 
         fti = getattr(self.portal.portal_types, "euphorie.module")
-        self.failUnless(isinstance(fti, ConditionalDexterityFTI))
+        self.assertTrue(isinstance(fti, ConditionalDexterityFTI))
 
     def testCanBeCopied(self):
         self.loginAsPortalOwner()
@@ -76,7 +79,7 @@ class ConstructionFilterTests(EuphorieIntegrationTestCase):
         self.loginAsPortalOwner()
         self.createStructure()
         types = [fti.id for fti in self.module.allowedContentTypes()]
-        self.failUnless("euphorie.module" in types)
+        self.assertTrue("euphorie.module" in types)
 
     def testMaxDepthInModule(self):
         self.loginAsPortalOwner()
@@ -84,30 +87,40 @@ class ConstructionFilterTests(EuphorieIntegrationTestCase):
         submodule = self._create(self.module, "euphorie.module", "module")
         subsubmodule = self._create(submodule, "euphorie.module", "module")
         types = [fti.id for fti in subsubmodule.allowedContentTypes()]
-        self.failUnless("euphorie.module" not in types)
+        self.assertTrue("euphorie.module" not in types)
 
     def testPreventModuleIfRiskExists(self):
         self.loginAsPortalOwner()
         self.createStructure()
         types = [fti.id for fti in self.module.allowedContentTypes()]
-        self.failUnless("euphorie.module" in types)
+        self.assertTrue("euphorie.module" in types)
         self._create(self.module, "euphorie.risk", "risk")
         types = [fti.id for fti in self.module.allowedContentTypes()]
-        self.failUnless("euphorie.module" not in types)
+        self.assertTrue("euphorie.module" not in types)
 
 
 class FunctionalTests(EuphorieFunctionalTestCase):
+
+    _default_credentials = {
+        "username": SITE_OWNER_NAME,
+        "password": SITE_OWNER_PASSWORD,
+    }
+
     def _create(self, container, *args, **kwargs):
-        newid = container.invokeFactory(*args, **kwargs)
-        return getattr(container, newid)
+        with api.env.adopt_user("admin"):
+            newid = container.invokeFactory(*args, **kwargs)
+            return getattr(container, newid)
 
     def createStructure(self):
-        self.country = self.portal.sectors.nl
-        self.sector = self._create(self.country, "euphorie.sector", "sector")
-        self.surveygroup = self._create(self.sector, "euphorie.surveygroup", "group")
-        self.survey = self._create(self.surveygroup, "euphorie.survey", "survey")
-        self.module = self._create(self.survey, "euphorie.module", "module")
-        commit()
+        with api.env.adopt_user("admin"):
+            self.country = self.portal.sectors.nl
+            self.sector = self._create(self.country, "euphorie.sector", "sector")
+            self.surveygroup = self._create(
+                self.sector, "euphorie.surveygroup", "group"
+            )
+            self.survey = self._create(self.surveygroup, "euphorie.survey", "survey")
+            self.module = self._create(self.survey, "euphorie.module", "module")
+            commit()
 
     def testEditTitleForModule(self):
         self.createStructure()
