@@ -9,7 +9,7 @@ from plonetheme.nuplone import MessageFactory as NuPloneMessageFactory
 from plonetheme.nuplone.utils import checkPermission
 from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
-from StringIO import StringIO
+from six import StringIO
 from zope.component import queryUtility
 from zope.i18nmessageid.message import Message
 from zope.interface import implementer
@@ -37,9 +37,7 @@ TAG = re.compile(u"<.*?>")
 UNWANTED = re.compile(u"(\r|&#13;|\xad)")
 WHITE = re.compile(" +")
 
-REGION_NAMES = {
-    "eu": _(u"European Union"),
-}
+REGION_NAMES = {"eu": _(u"European Union")}
 
 CUSTOM_COUNTRY_NAMES = {
     # This are areas whose country codes have not stabilized enough
@@ -195,7 +193,8 @@ class ToolTypesInfo(object):
     @property
     def default_tool_type(self):
         # The one defined as first option wins
-        return TOOL_TYPES.keys()[0]
+        for key in TOOL_TYPES:
+            return key
 
 
 def get_tool_type_default():
@@ -414,8 +413,7 @@ class UserExportCSV(BrowserView):
         buffer.close()
         response = self.request.RESPONSE
         response.setHeader(
-            "Content-Disposition",
-            "attachment; filename=oira_admin_users.csv",
+            "Content-Disposition", "attachment; filename=oira_admin_users.csv"
         )
         response.setHeader("Content-Type", "text/csv;charset=utf-8")
         return csv_data
